@@ -1,4 +1,3 @@
-PASSWORDLESS_AUTHENTICATED_URL = "/account/"
 PASSWORDLESS_HASH_SALT = "omg123"
 PASSWORDLESS_MAX_REQUEST_AGE = 3600
 PASSWORDLESS_MAX_REQUEST_COUNT = 3
@@ -6,4 +5,4 @@ PASSWORDLESS_MAX_REQUEST_FAILURES = 3
 PASSWORDLESS_OTP_DICTIONARY = "BCDFGHJKLMNPQRSTVWXYZ123456789"
 PASSWORDLESS_OTP_LENGTH = 6
 PASSWORDLESS_REGISTRATION_ENABLED = True
-PASSWORDLESS_USE_CELERY = True
+PASSWORDLESS_USE_CELERY = False
